
```bash
uv run python -m build   
uv run twine upload dist/*
```

```txt
🧹 优化/重构
📝 更新文档
🐛 修复 Bug
🔥 移除代码或文件
♻️ 重构代码
✨ 添加新功能
```

## [v0.2.3] 
- 2025-10-29
- ✨ 添加 load_toml
- 修改 readme.md 格式

## [v2025.12.01]
- ✨ 增加 datalake 
    - 本地简单数据库
    - 方便统一新文件名
    - 创建新文件，获取对应时间的文件